==> aws-cdk-lib-2.51.1-sources.jar: software/amazon/awscdk/cloudassembly/schema/LoadManifestOptions.java <==
package software.amazon.awscdk.cloudassembly.schema;

/**
 * Options for the loadManifest operation.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.cloudassembly.schema.*;
 * LoadManifestOptions loadManifestOptions = LoadManifestOptions.builder()
 *         .skipEnumCheck(false)
 *         .skipVersionCheck(false)
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-11-18T21:59:15.685Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.cloud_assembly_schema.LoadManifestOptions")
@software.amazon.jsii.Jsii.Proxy(LoadManifestOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface LoadManifestOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * Skip enum checks.
     * <p>
     * This means you may read enum values you don't know about yet. Make sure to always
     * check the values of enums you encounter in the manifest.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getSkipEnumCheck() {
        return null;
    }

    /**
     * Skip the version check.
     * <p>
     * This means you may read a newer cloud assembly than the CX API is designed
     * to support, and your application may not be aware of all features that in use
     * in the Cloud Assembly.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getSkipVersionCheck() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link LoadManifestOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link LoadManifestOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<LoadManifestOptions> {
        java.lang.Boolean skipEnumCheck;
        java.lang.Boolean skipVersionCheck;

        /**
         * Sets the value of {@link LoadManifestOptions#getSkipEnumCheck}
         * @param skipEnumCheck Skip enum checks.
         *                      This means you may read enum values you don't know about yet. Make sure to always
         *                      check the values of enums you encounter in the manifest.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder skipEnumCheck(java.lang.Boolean skipEnumCheck) {
            this.skipEnumCheck = skipEnumCheck;
            return this;
        }

        /**
         * Sets the value of {@link LoadManifestOptions#getSkipVersionCheck}
         * @param skipVersionCheck Skip the version check.
         *                         This means you may read a newer cloud assembly than the CX API is designed
         *                         to support, and your application may not be aware of all features that in use
         *                         in the Cloud Assembly.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder skipVersionCheck(java.lang.Boolean skipVersionCheck) {
            this.skipVersionCheck = skipVersionCheck;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link LoadManifestOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public LoadManifestOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link LoadManifestOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements LoadManifestOptions {
        private final java.lang.Boolean skipEnumCheck;
        private final java.lang.Boolean skipVersionCheck;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.skipEnumCheck = software.amazon.jsii.Kernel.get(this, "skipEnumCheck", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.skipVersionCheck = software.amazon.jsii.Kernel.get(this, "skipVersionCheck", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.skipEnumCheck = builder.skipEnumCheck;
            this.skipVersionCheck = builder.skipVersionCheck;
        }

        @Override
        public final java.lang.Boolean getSkipEnumCheck() {
            return this.skipEnumCheck;
        }

        @Override
        public final java.lang.Boolean getSkipVersionCheck() {
            return this.skipVersionCheck;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getSkipEnumCheck() != null) {
                data.set("skipEnumCheck", om.valueToTree(this.getSkipEnumCheck()));
            }
            if (this.getSkipVersionCheck() != null) {
                data.set("skipVersionCheck", om.valueToTree(this.getSkipVersionCheck()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.cloud_assembly_schema.LoadManifestOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            LoadManifestOptions.Jsii$Proxy that = (LoadManifestOptions.Jsii$Proxy) o;

            if (this.skipEnumCheck != null ? !this.skipEnumCheck.equals(that.skipEnumCheck) : that.skipEnumCheck != null) return false;
            return this.skipVersionCheck != null ? this.skipVersionCheck.equals(that.skipVersionCheck) : that.skipVersionCheck == null;
        }

        @Override
        public final int hashCode() {
            int result = this.skipEnumCheck != null ? this.skipEnumCheck.hashCode() : 0;
            result = 31 * result + (this.skipVersionCheck != null ? this.skipVersionCheck.hashCode() : 0);
            return result;
        }
    }
}

==> aws-cdk-lib-2.130.0-sources.jar: software/amazon/awscdk/cloudassembly/schema/LoadManifestOptions.java <==
package software.amazon.awscdk.cloudassembly.schema;

/**
 * Options for the loadManifest operation.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.cloudassembly.schema.*;
 * LoadManifestOptions loadManifestOptions = LoadManifestOptions.builder()
 *         .skipEnumCheck(false)
 *         .skipVersionCheck(false)
 *         .topoSort(false)
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-02-23T02:06:41.208Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.cloud_assembly_schema.LoadManifestOptions")
@software.amazon.jsii.Jsii.Proxy(LoadManifestOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface LoadManifestOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * Skip enum checks.
     * <p>
     * This means you may read enum values you don't know about yet. Make sure to always
     * check the values of enums you encounter in the manifest.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getSkipEnumCheck() {
        return null;
    }

    /**
     * Skip the version check.
     * <p>
     * This means you may read a newer cloud assembly than the CX API is designed
     * to support, and your application may not be aware of all features that in use
     * in the Cloud Assembly.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getSkipVersionCheck() {
        return null;
    }

    /**
     * Topologically sort all artifacts.
     * <p>
     * This parameter is only respected by the constructor of <code>CloudAssembly</code>. The
     * property lives here for backwards compatibility reasons.
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getTopoSort() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link LoadManifestOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link LoadManifestOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<LoadManifestOptions> {
        java.lang.Boolean skipEnumCheck;
        java.lang.Boolean skipVersionCheck;
        java.lang.Boolean topoSort;

        /**
         * Sets the value of {@link LoadManifestOptions#getSkipEnumCheck}
         * @param skipEnumCheck Skip enum checks.
         *                      This means you may read enum values you don't know about yet. Make sure to always
         *                      check the values of enums you encounter in the manifest.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder skipEnumCheck(java.lang.Boolean skipEnumCheck) {
            this.skipEnumCheck = skipEnumCheck;
            return this;
        }

        /**
         * Sets the value of {@link LoadManifestOptions#getSkipVersionCheck}
         * @param skipVersionCheck Skip the version check.
         *                         This means you may read a newer cloud assembly than the CX API is designed
         *                         to support, and your application may not be aware of all features that in use
         *                         in the Cloud Assembly.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder skipVersionCheck(java.lang.Boolean skipVersionCheck) {
            this.skipVersionCheck = skipVersionCheck;
            return this;
        }

        /**
         * Sets the value of {@link LoadManifestOptions#getTopoSort}
         * @param topoSort Topologically sort all artifacts.
         *                 This parameter is only respected by the constructor of <code>CloudAssembly</code>. The
         *                 property lives here for backwards compatibility reasons.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder topoSort(java.lang.Boolean topoSort) {
            this.topoSort = topoSort;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link LoadManifestOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public LoadManifestOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link LoadManifestOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements LoadManifestOptions {
        private final java.lang.Boolean skipEnumCheck;
        private final java.lang.Boolean skipVersionCheck;
        private final java.lang.Boolean topoSort;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.skipEnumCheck = software.amazon.jsii.Kernel.get(this, "skipEnumCheck", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.skipVersionCheck = software.amazon.jsii.Kernel.get(this, "skipVersionCheck", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.topoSort = software.amazon.jsii.Kernel.get(this, "topoSort", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.skipEnumCheck = builder.skipEnumCheck;
            this.skipVersionCheck = builder.skipVersionCheck;
            this.topoSort = builder.topoSort;
        }

        @Override
        public final java.lang.Boolean getSkipEnumCheck() {
            return this.skipEnumCheck;
        }

        @Override
        public final java.lang.Boolean getSkipVersionCheck() {
            return this.skipVersionCheck;
        }

        @Override
        public final java.lang.Boolean getTopoSort() {
            return this.topoSort;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getSkipEnumCheck() != null) {
                data.set("skipEnumCheck", om.valueToTree(this.getSkipEnumCheck()));
            }
            if (this.getSkipVersionCheck() != null) {
                data.set("skipVersionCheck", om.valueToTree(this.getSkipVersionCheck()));
            }
            if (this.getTopoSort() != null) {
                data.set("topoSort", om.valueToTree(this.getTopoSort()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.cloud_assembly_schema.LoadManifestOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            LoadManifestOptions.Jsii$Proxy that = (LoadManifestOptions.Jsii$Proxy) o;

            if (this.skipEnumCheck != null ? !this.skipEnumCheck.equals(that.skipEnumCheck) : that.skipEnumCheck != null) return false;
            if (this.skipVersionCheck != null ? !this.skipVersionCheck.equals(that.skipVersionCheck) : that.skipVersionCheck != null) return false;
            return this.topoSort != null ? this.topoSort.equals(that.topoSort) : that.topoSort == null;
        }

        @Override
        public final int hashCode() {
            int result = this.skipEnumCheck != null ? this.skipEnumCheck.hashCode() : 0;
            result = 31 * result + (this.skipVersionCheck != null ? this.skipVersionCheck.hashCode() : 0);
            result = 31 * result + (this.topoSort != null ? this.topoSort.hashCode() : 0);
            return result;
        }
    }
}
